@@ -12,7 +12,7 @@ from .five import items, python_2_unicode_compatible, text_t, values
 from .serialization import dumps, prepare_accept_content
 from .utils.functional import ChannelPromise, maybe_list
 
-__all__ = ['Exchange', 'Queue', 'Producer', 'Consumer']
+__all__ = ('Exchange', 'Queue', 'Producer', 'Consumer')
 
 
 @python_2_unicode_compatible
@@ -21,7 +21,7 @@ class Producer(object):
 
     Arguments:
         channel (kombu.Connection, ChannelT): Connection or channel.
-        exchange (Exchange, str): Optional default exchange.
+        exchange (kombu.entity.Exchange, str): Optional default exchange.
         routing_key (str): Optional default routing key.
         serializer (str): Default serializer. Default is `"json"`.
         compression (str): Default compression method.
@@ -118,7 +118,8 @@ class Producer(object):
                 mandatory=False, immediate=False, priority=0,
                 content_type=None, content_encoding=None, serializer=None,
                 headers=None, compression=None, exchange=None, retry=False,
-                retry_policy=None, declare=[], expiration=None, **properties):
+                retry_policy=None, declare=None, expiration=None,
+                **properties):
         """Publish message to the specified exchange.
 
         Arguments:
@@ -134,7 +135,7 @@ class Producer(object):
             compression (str): Compression method to use.  Default is none.
             headers (Dict): Mapping of arbitrary headers to pass along
                 with the message body.
-            exchange (Exchange, str): Override the exchange.
+            exchange (kombu.entity.Exchange, str): Override the exchange.
                 Note that this exchange must have been declared.
             declare (Sequence[EntityT]): Optional list of required entities
                 that must have been declared before publishing the message.
@@ -150,6 +151,7 @@ class Producer(object):
         """
         _publish = self._publish
 
+        declare = [] if declare is None else declare
         headers = {} if headers is None else headers
         retry_policy = {} if retry_policy is None else retry_policy
         routing_key = self.routing_key if routing_key is None else routing_key
@@ -167,8 +169,9 @@ class Producer(object):
             compression, headers)
 
         if self.auto_declare and self.exchange.name:
-            declare = [] if declare is None else declare
-            declare.append(self.exchange)
+            if self.exchange not in declare:
+                # XXX declare should be a Set.
+                declare.append(self.exchange)
 
         if retry:
             _publish = self.connection.ensure(self, _publish, **retry_policy)
@@ -394,7 +397,8 @@ class Consumer(object):
         """Revive consumer after connection loss."""
         self._active_tags.clear()
         channel = self.channel = maybe_channel(channel)
-        for qname, queue in items(self._queues):
+        # modify dict size while iterating over it is not allowed
+        for qname, queue in list(items(self._queues)):
             # name may have changed after declare
             self._queues.pop(qname, None)
             queue = self._queues[queue.name] = queue(self.channel)
@@ -430,11 +434,14 @@ class Consumer(object):
         self.consume()
         return self
 
-    def __exit__(self, *exc_info):
-        try:
-            self.cancel()
-        except Exception:
-            pass
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        if self.channel and self.channel.connection:
+            conn_errors = self.channel.connection.client.connection_errors
+            if not isinstance(exc_val, conn_errors):
+                try:
+                    self.cancel()
+                except Exception:
+                    pass
 
     def add_queue(self, queue):
         """Add a queue to the list of queues to consume from.
